Module object_store

Module object_store 

Extend object_store::ObjectStore functionalities

Re-exports

pub use providers::ObjectStoreProvider;
pub use providers::ObjectStoreRegistry;
pub use storage_options::EXPIRES_AT_MILLIS_KEY;
pub use storage_options::LanceNamespaceStorageOptionsProvider;
pub use storage_options::REFRESH_OFFSET_MILLIS_KEY;
pub use storage_options::StorageOptionsAccessor;
pub use storage_options::StorageOptionsProvider;

Modules

providers
storage_options
Storage options provider and accessor for dynamic credential fetching

Structs

ChainedWrappingObjectStore
ObjectStore
Wraps ObjectStore
ObjectStoreParams
Parameters to create an ObjectStore
StorageOptions

Enums

LanceConfigKey
Options that can be set for multiple object stores

Constants

DEFAULT_CLOUD_IO_PARALLELISM
DEFAULT_DOWNLOAD_RETRY_COUNT
DEFAULT_LOCAL_IO_PARALLELISM

Statics

DEFAULT_MAX_IOP_SIZE

Traits

ObjectStoreExt
WrappingObjectStore

Functions

uri_to_url
Convert a URI string or local path to a URL