pub struct StorageOptions(pub HashMap<String, String>);Tuple Fields
0: HashMap<String, String>Implementations
Sourceimpl StorageOptions
impl StorageOptions
Sourcepub fn with_env_s3(&mut self)
pub fn with_env_s3(&mut self)
Add values from the environment to storage options
Sourcepub fn as_s3_options(&self) -> HashMap<AmazonS3ConfigKey, String>
pub fn as_s3_options(&self) -> HashMap<AmazonS3ConfigKey, String>
Subset of options relevant for s3 storage
Sourceimpl StorageOptions
impl StorageOptions
Sourcepub fn with_env_azure(&mut self)
pub fn with_env_azure(&mut self)
Add values from the environment to storage options
Sourcepub fn as_azure_options(&self) -> HashMap<AzureConfigKey, String>
pub fn as_azure_options(&self) -> HashMap<AzureConfigKey, String>
Subset of options relevant for azure storage
Sourceimpl StorageOptions
impl StorageOptions
Sourcepub fn with_env_gcs(&mut self)
pub fn with_env_gcs(&mut self)
Add values from the environment to storage options
Sourcepub fn as_gcs_options(&self) -> HashMap<GoogleConfigKey, String>
pub fn as_gcs_options(&self) -> HashMap<GoogleConfigKey, String>
Subset of options relevant for gcs storage
Sourceimpl StorageOptions
impl StorageOptions
Sourcepub fn allow_http(&self) -> bool
pub fn allow_http(&self) -> bool
Denotes if unsecure connections via http are allowed
Sourcepub fn download_retry_count(&self) -> usize
pub fn download_retry_count(&self) -> usize
Number of times to retry a download that fails
Sourcepub fn client_max_retries(&self) -> usize
pub fn client_max_retries(&self) -> usize
Max retry times to set in RetryConfig for object store client
Sourcepub fn client_retry_timeout(&self) -> u64
pub fn client_retry_timeout(&self) -> u64
Seconds of timeout to set in RetryConfig for object store client
pub fn get(&self, key: &str) -> Option<&String>
Sourcepub fn client_options(&self) -> Result<ClientOptions>
pub fn client_options(&self) -> Result<ClientOptions>
Build ClientOptions with default headers extracted from headers.* keys.
Keys prefixed with headers. are parsed into HTTP headers. For example,
headers.x-ms-version = 2023-11-03 results in a default header
x-ms-version: 2023-11-03.
Returns an error if any headers.* key has an invalid header name or value.
Sourcepub fn expires_at_millis(&self) -> Option<u64>
pub fn expires_at_millis(&self) -> Option<u64>
Get the expiration time in milliseconds since epoch, if present