Writer

Trait Writer 

pub trait Writer:
    AsyncWrite
    + Unpin
    + Send {
    // Required methods
    fn tell<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<usize>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn shutdown<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<WriteResult>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
A trait for writing to a file on local file system or object store.

Required Methods

fn tell<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<usize>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Tell the current offset.

fn shutdown<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<WriteResult>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Flush all buffered data and finalize the write, returning metadata about the written object.