pub struct IOTracker(/* private fields */);Implementations
Sourceimpl IOTracker
impl IOTracker
Sourcepub fn incremental_stats(&self) -> IoStats
pub fn incremental_stats(&self) -> IoStats
Get IO statistics and reset the counters (incremental pattern).
This returns the accumulated statistics since the last call and resets the internal counters to zero.
Sourcepub fn stats(&self) -> IoStats
pub fn stats(&self) -> IoStats
Get a snapshot of current IO statistics without resetting counters.
This returns a clone of the current statistics without modifying the internal state. Use this when you need to check stats without resetting.
Sourcepub fn record_read(
&self,
method: &'static str,
path: Path,
num_bytes: u64,
range: Option<Range<u64>>,
)
pub fn record_read( &self, method: &'static str, path: Path, num_bytes: u64, range: Option<Range<u64>>, )
Record a read operation for tracking.
This is used by readers that bypass the ObjectStore layer (like LocalObjectReader) to ensure their IO operations are still tracked.
Sourcepub fn record_write(&self, method: &'static str, path: Path, num_bytes: u64)
pub fn record_write(&self, method: &'static str, path: Path, num_bytes: u64)
Record a write operation for tracking.
This is used by writers that bypass the ObjectStore layer (like LocalWriter) to ensure their IO operations are still tracked.