Extend object_store::ObjectStore functionalities
Re-exports
pub use providers::ObjectStoreProvider;pub use providers::ObjectStoreRegistry;pub use storage_options::EXPIRES_AT_MILLIS_KEY;pub use storage_options::LanceNamespaceStorageOptionsProvider;pub use storage_options::REFRESH_OFFSET_MILLIS_KEY;pub use storage_options::StorageOptionsAccessor;pub use storage_options::StorageOptionsProvider;
Modules
- providers
- storage_
options - Storage options provider and accessor for dynamic credential fetching
Structs
- Chained
Wrapping Object Store - Object
Store - Wraps ObjectStore
- Object
Store Params - Parameters to create an ObjectStore
- Storage
Options
Enums
- Lance
Config Key - Options that can be set for multiple object stores
Constants
Statics
Traits
Functions
- uri_
to_ url - Convert a URI string or local path to a URL