pub struct LocalSpillStore { /* private fields */ }Expand description
A SpillStore that writes temporary files to a local temp directory.
By default there is no disk cap. Use LocalSpillStore::with_cap to
configure one shared across every handle this store produces.
The temp directory is deleted when the store is dropped, cleaning up any files whose handles have already been dropped.
Implementations